-- name: [CS] Croc
-- description: The Hero of the Gobbos!\n\n\\#ff7777\\This Pack requires Character Select\nto use as a Library!

--[[
    API Documentation for Character Select can be found below:
    https://github.com/Squishy6094/character-select-coop/wiki/API-Documentation

    Use this if you're curious on how anything here works >v<
	(This is an edited version of the Template File by Squishy)
]]

local TEXT_MOD_NAME = "Croc"

-- Stops mod from loading if Character Select isn't on
if not _G.charSelectExists then
    djui_popup_create("\\#ffffdc\\\n"..TEXT_MOD_NAME.."\nRequires the Character Select Mod\nto use as a Library!\n\nPlease turn on the Character Select Mod\nand Restart the Room!", 6)
    return 0
end

local E_MODEL_CUSTOM_MODEL = smlua_model_util_get_id("croc_geo") -- Located in "actors"

local TEX_CUSTOM_LIFE_ICON = get_texture_info("croc_icon") -- Located in "textures"

-- All Located in "sound" Name them whatever you want.
local VOICETABLE_CROC = {
    --[CHAR_SOUND_OKEY_DOKEY] = 'StartLevel.ogg', -- Starting game
	[CHAR_SOUND_LETS_A_GO] = 'Silent.ogg', -- Starting level
	[CHAR_SOUND_PUNCH_YAH] = 'Croc26.ogg', -- Punch 1
	[CHAR_SOUND_PUNCH_WAH] = 'Croc27.ogg', -- Punch 2
	[CHAR_SOUND_PUNCH_HOO] = 'Croc28.ogg', -- Punch 3
	[CHAR_SOUND_YAH_WAH_HOO] = 'Croc25.ogg', -- First/Second jump sounds
	[CHAR_SOUND_HOOHOO] = 'Croc9.ogg', -- Third jump sound
	[CHAR_SOUND_YAHOO_WAHA_YIPPEE] = 'Croc11.ogg', -- Triple jump sounds
	[CHAR_SOUND_UH] = 'Croc22.ogg', -- Wall bonk
	[CHAR_SOUND_UH2] = 'Silent.ogg', -- Landing after long jump
	[CHAR_SOUND_UH2_2] = 'Silent.ogg', -- Same sound as UH2; jumping onto ledge
	[CHAR_SOUND_HAHA] = 'Silent.ogg', -- Landing triple jump
	[CHAR_SOUND_YAHOO] = 'Croc11.ogg', -- Long jump
	[CHAR_SOUND_DOH] = 'Croc22.ogg', -- Long jump wall bonk
	[CHAR_SOUND_WHOA] = 'Croc3.ogg', -- Grabbing ledge
	[CHAR_SOUND_EEUH] = 'Silent.ogg', -- Climbing over ledge
	[CHAR_SOUND_WAAAOOOW] = 'Croc18.ogg', -- Falling a long distance
	[CHAR_SOUND_TWIRL_BOUNCE] = 'Croc10.ogg', -- Bouncing off of a flower spring
	[CHAR_SOUND_GROUND_POUND_WAH] = 'Silent.ogg', 
	[CHAR_SOUND_HRMM] = 'Croc4.ogg', -- Lifting something
	[CHAR_SOUND_HERE_WE_GO] = 'Croc10.ogg', -- Star get
	[CHAR_SOUND_SO_LONGA_BOWSER] = 'Croc28.ogg', -- Throwing Bowser
--DAMAGE
	[CHAR_SOUND_ATTACKED] = {'Croc21.ogg', 'Croc22.ogg', 'Croc23.ogg'}, -- Damaged
	[CHAR_SOUND_PANTING] = 'Croc7.ogg', -- Low health
	[CHAR_SOUND_ON_FIRE] = {'Croc13.ogg','Croc14.ogg'}, -- Burned
--SLEEP SOUNDS
	[CHAR_SOUND_IMA_TIRED] = 'Croc24.ogg', -- Mario feeling tired
	[CHAR_SOUND_YAWNING] = 'Croc16.ogg', -- Mario yawning before he sits down to sleep
	[CHAR_SOUND_SNORING1] = 'Silent.ogg', -- Snore Inhale
	[CHAR_SOUND_SNORING2] = 'Silent.ogg', -- Exhale
	[CHAR_SOUND_SNORING3] = 'Silent.ogg', -- Sleep talking / mumbling
--COUGHING (USED IN THE GAS MAZE)
	[CHAR_SOUND_COUGHING1] = 'Silent.ogg', -- Cough take 1
	[CHAR_SOUND_COUGHING2] = 'Silent.ogg', -- Cough take 2
	[CHAR_SOUND_COUGHING3] = 'Silent.ogg', -- Cough take 3
--DEATH
	[CHAR_SOUND_DYING] = {'Croc16.ogg', 'Croc17.ogg'}, -- Dying from damage
	[CHAR_SOUND_DROWNING] = 'Silent.ogg', -- Running out of air underwater
	[CHAR_SOUND_MAMA_MIA] = 'Croc24.ogg' -- Booted out of level
}

-- All Located in "actors"
local CAPTABLE_CROC = {
    normal = smlua_model_util_get_id("crocnormal_geo"),
    wing = smlua_model_util_get_id("crocwing_geo"),
    metal = smlua_model_util_get_id("crocmetal_geo"),
}

local PALETTE_CHAR = {
    [PANTS]  = "ffffff",
    [SHIRT]  = "DEDE29",
    [GLOVES] = "ffffff",
    [SHOES]  = "C67B42",
    [HAIR]   = "5AB500",
    [SKIN]   = "ffffff",
    [CAP]    = "ffffff",
	[EMBLEM] = "ffffff"
}

local HM_CROC= {
    label = {
        left = get_texture_info("CrocHealthL"),
        right = get_texture_info("CrocHealthR"),
    },
    pie = {
        [1] = get_texture_info("Pie1"),
        [2] = get_texture_info("Pie2"),
        [3] = get_texture_info("Pie3"),
        [4] = get_texture_info("Pie4"),
        [5] = get_texture_info("Pie5"),
        [6] = get_texture_info("Pie6"),
        [7] = get_texture_info("Pie7"),
        [8] = get_texture_info("Pie8"),
    }
}

local CSloaded = false
local function on_character_select_load()
    CT_CROC = _G.charSelect.character_add("Croc", {"The Hero of the Gobbos!","Despite being a carnivore, he'd like","to eat some piece of Princess Peach's","delicious cake!"}, "HeavenlyTape", {r = 90, g = 181, b = 0}, E_MODEL_CUSTOM_MODEL, CT_CROC, TEX_CUSTOM_LIFE_ICON)
    _G.charSelect.character_add_caps(E_MODEL_CUSTOM_MODEL, CAPTABLE_CHAR)
    _G.charSelect.character_add_voice(E_MODEL_CUSTOM_MODEL, VOICETABLE_CROC)
    _G.charSelect.character_add_celebration_star(E_MODEL_CUSTOM_MODEL, E_MODEL_CUSTOM_STAR, TEX_CUSTOM_STAR_ICON)
    _G.charSelect.character_add_palette_preset(E_MODEL_CUSTOM_MODEL, PALETTE_CHAR)
    _G.charSelect.character_add_health_meter(CT_CROC, HM_CROC)

    CSloaded = true
end

local function on_character_sound(m, sound)
    if not CSloaded then return end
    if _G.charSelect.character_get_voice(m) == VOICETABLE_CROC then return _G.charSelect.voice.sound(m, sound) end
end

local function on_character_snore(m)
    if not CSloaded then return end
    if _G.charSelect.character_get_voice(m) == VOICETABLE_CROC then return _G.charSelect.voice.snore(m) end
end

hook_event(HOOK_ON_MODS_LOADED, on_character_select_load)
hook_event(HOOK_CHARACTER_SOUND, on_character_sound)
hook_event(HOOK_MARIO_UPDATE, on_character_snore)